
# This file was generated by 'versioneer.py' (0.17) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2018-03-08T15:37:31-0600",
 "dirty": false,
 "error": null,
 "full-revisionid": "6b8f4b57f559b18d0b671257f7d58b571f90b45e",
 "version": "3.7.1"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
